import datetime
import re

import dateutil
import dateutil.parser

from em_tasks import logger
from em_tasks.google.sheet_api import SheetAPI


class ShipmentReader(object):
  pass


class GSheetShipmentReader(ShipmentReader):
  def __init__(self, sheet_api):
    self.sheet_api = sheet_api

  def read(self, spreadsheet_id):
    logger.debug('[SheetProcessing] %s', spreadsheet_id)

    spreadsheet = self.sheet_api.get_spreadsheet(spreadsheet_id)
    if not spreadsheet:
      logger.error('[SpreadSheetNotFound] %s', spreadsheet_id)
      return

    worksheets = self.sheet_api.get_worksheets(spreadsheet)
    for worksheet in worksheets:
      records = []
      name = worksheet.title
      if name.find('20231205~') == -1 and name != 'US' and name != 'UK/CA':
      # if name != 'US' and name != 'UK/CA':
        continue

      logger.debug('[Sheet] SheetID: %s, SheetName: %s', spreadsheet_id, name)

      vals = self.sheet_api.get_worksheet_vals(worksheet)
      headers = None
      for row in vals:
        if not headers:
          if 'tracking' not in row and 'TRACKING#' not in row and 'Carrier' not in row:
            continue

          headers = [col.lower().strip('#') for col in row]
          continue

        empty = True
        for col in row:
          if col:
            empty = False
            break

        if empty:
          continue

        record = {'spreadsheet_id': spreadsheet_id, 'sheet': name}
        for idx, header in enumerate(headers):
          try:
            record[header] = row[idx]
          except Exception as e:
            logger.exception(e)

        records.append(record)

      yield (worksheet, headers, records)
